"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cp = require("child_process");
require("tyranid/builtin/server");
const tyr_1 = require("./tyr");
const collection_1 = require("./core/collection");
const _ = require("lodash");
const Tyr = tyr_1.default;
exports.Job = new collection_1.default({
    id: '_j0',
    name: 'tyrJob',
    internal: true,
    fields: {
        _id: { is: 'mongoid' },
        collection: { is: 'string' },
        service: { is: 'string' },
        parameters: {
            is: 'string',
            note: 'This has a stringified version of the parameters',
        },
        user: { link: 'user?' },
        queuedAt: { is: 'datetime' },
        startAt: { is: 'datetime' },
        endAt: { is: 'datetime' },
        canceled: { is: 'boolean' },
        exception: { is: 'text' },
    },
    indexes: [
        {
            key: {
                startAt: 1,
                queuedAt: 1,
            },
        },
    ],
});
exports.submitJob = async (collection, methodName, parameters, user) => {
    //const method = collection.def.service![methodName];
    await exports.Job.db.insertOne({
        collection: collection.id,
        service: methodName,
        parameters: JSON.stringify(parameters),
        user: user === null || user === void 0 ? void 0 : user.$id,
        queuedAt: new Date(),
    });
};
let currentJob;
exports.processJob = async () => {
    const jobdb = exports.Job.db;
    const rslt = await jobdb.findOneAndUpdate({ startAt: null }, { $set: { startAt: new Date() } }, { sort: { queuedAt: 1 } });
    const { value } = rslt;
    if (value) {
        try {
            const { _id: jobId, collection: collectionId, service: methodName, parameters, } = value;
            currentJob = value;
            Tyr.isCurrentJobCanceled = !!(currentJob === null || currentJob === void 0 ? void 0 : currentJob.canceled);
            const collection = Tyr.byId[collectionId];
            const args = JSON.parse(parameters);
            jobdb.updateOne({ _id: value._id }, { $set: { startAt: new Date() } });
            await collection.service[methodName].apply({
                source: 'job',
                user: undefined,
                req: undefined,
                collection,
                job: jobId,
            }, args);
            jobdb.updateOne({ _id: value._id }, { $set: { endAt: new Date() } });
        }
        catch (err) {
            console.log(err);
            jobdb.updateOne({ _id: value._id }, { $set: { endAt: new Date(), exception: JSON.stringify(err) } });
        }
        return true;
    }
    return false;
};
exports.processJobs = async () => {
    let waitMs = 1000;
    for (;;) {
        if (!(await exports.processJob())) {
            await Tyr.sleep(waitMs);
            waitMs *= 2;
            if (waitMs > 30000)
                waitMs = 30000;
        }
        else {
            waitMs = 1000;
        }
    }
};
exports.isJobWorker = (Tyr.isJobWorker = () => process.env.TYR_SERVER_ROLE === 'job');
exports.handleJobWorker = (Tyr.handleJobWorker = async () => {
    if (exports.isJobWorker()) {
        await exports.processJobs();
        return true;
    }
    return false;
});
exports.spawnJobWorker = (Tyr.spawnJobWorker = () => {
    process.execArgv = _.without(process.execArgv, '--inspect');
    /*const worker = */ cp.fork(process.argv[1], undefined, {
        env: { ...process.env, TYR_SERVER_ROLE: 'job' },
    });
    // TODO:  what, if anything, do we need to do with this worker?
});
exports.Job.boot = async (stage, pass) => {
    if (stage === 'link') {
        exports.Job.on({
            type: 'change',
            when: 'post',
            handler: async (event) => {
                const job = await event.document;
                if (job && job.$id === (currentJob === null || currentJob === void 0 ? void 0 : currentJob._id)) {
                    Tyr.currrentJobIsCanceled = true;
                }
            },
        });
    }
};
//# sourceMappingURL=job.js.map