"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const type_1 = require("../core/type");
const EmailType = new type_1.default({
    name: 'email',
    typescript: 'string',
    compare(field, a, b) {
        return a.localeCompare(b, undefined, { sensitivity: 'base' });
    },
    query(path, where, query) {
        if (where) {
            query[path.name] = _.isArray(where) ? { $in: where } : where;
        }
    },
    matches(path, where, doc) {
        if (where) {
            let value = path.get(doc);
            if (value) {
                if (!_.isString(value)) {
                    value = '' + value;
                }
                if (_.isArray(where)) {
                    return where.indexOf(value) >= 0;
                }
                else if (where instanceof RegExp) {
                    return value.match(where);
                }
                else {
                    return value === where;
                }
            }
        }
        return true;
    },
});
exports.default = EmailType;
//# sourceMappingURL=email.js.map