"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const tyr_1 = require("../tyr");
const collection_1 = require("../core/collection");
const type_1 = require("../core/type");
function validateUidCollection(validator, path, collection) {
    function fail() {
        throw validator.err(path, `Unknown collection referenced in a uid "of" -- ${JSON.stringify(collection, null, 2)}`);
    }
    if (collection instanceof collection_1.default) {
        if (!tyr_1.default.byId[collection.id]) {
            fail();
        }
    }
    else if (typeof collection === 'string') {
        if (!tyr_1.default.byId[collection] && !tyr_1.default.byName[collection]) {
            fail();
        }
    }
    else {
        fail();
    }
}
const UidType = new type_1.default({
    name: 'uid',
    typescript: 'string',
    compile(compiler, field) {
        if (compiler.stage !== 'link')
            return;
        let of = field.def.of;
        if (!of) {
            return;
        }
        if (!Array.isArray(of)) {
            of = [of];
        }
        field.of = of.map(cid => {
            validateUidCollection(compiler, field.pathName, cid);
            return cid instanceof tyr_1.default.Collection
                ? cid
                : tyr_1.default.byId[cid] || tyr_1.default.byName[cid];
        });
    },
});
collection_1.default.prototype.isUid = function (uid) {
    return uid && uid.substring(0, 3) === this.id;
};
/** @isomorphic */
tyr_1.default.parseUid = function (uid) {
    const colId = uid.substring(0, 3);
    const col = tyr_1.default.byId[colId];
    if (!col) {
        throw new Error('No collection found for id "' + colId + '"');
    }
    const strId = uid.substring(3);
    const idType = col.fields[col.def.primaryKey.field].type;
    return {
        collection: col,
        id: idType.fromString ? idType.fromString(strId) : strId,
    };
};
/** @isomorphic */
tyr_1.default.byUid = function (uid, opts) {
    const p = tyr_1.default.parseUid(uid);
    return p.collection.byId(p.id, opts);
};
tyr_1.default.byUids = async function (uids, opts) {
    const byColId = {};
    for (const uid of uids) {
        const { collection, id } = tyr_1.default.parseUid(uid), colId = collection.id;
        const colUids = byColId[colId];
        if (!colUids) {
            byColId[colId] = [id];
        }
        else {
            colUids.push(id);
        }
    }
    const docsByUid = {};
    await Promise.all(_.map(byColId, async (ids, colId) => {
        const docs = await tyr_1.default.byId[colId].byIds(ids, opts);
        for (const doc of docs) {
            docsByUid[doc.$uid] = doc;
        }
    }));
    return uids.map(uid => docsByUid[uid]);
};
exports.default = UidType;
//# sourceMappingURL=uid.js.map